@@ -675,13 +675,17 @@ def docParser(docstring: str):
   out['top-descr'] = descr
   return out
 
-def paramWindow(param: Parameter):
+def paramWindow(param: Parameter, modal=True):
   tree = flexibleParamTree(param)
   setParamsExpanded(tree, True)
   dlg = QtWidgets.QDialog()
   layout = QtWidgets.QVBoxLayout()
   dlg.setLayout(layout)
+  dlg.setModal(modal)
   layout.addWidget(tree)
+  # Show before exec so size calculations are correct, and fix the height by a small factor
+  dlg.show()
+  dlg.resize(dlg.width(), dlg.height() + 25)
   dlg.exec_()
 
 def hookupParamWidget(param: Parameter, widget):
