@@ -68,12 +68,13 @@ class Action:
       i.e. performing a redo when that redo may not have a corresponding undo again
     """
     self._runner = self._generator(*self.args, **self.kwargs)
+    if not graceful:
+      ret = next(self._runner)
+    else:
+      ret = gracefulNext(self._runner)
     # Forward use is expired, so treat as backward now
     self.treatAsUndo = True
-    if not graceful:
-      return next(self._runner)
-    else:
-      return gracefulNext(self._runner)
+    return ret
 
   def backward(self):
     """Undo the action"""
@@ -155,7 +156,7 @@ class ActionStack:
       def inner_group(*args, **kwargs):
         with self.group(descr, flushUnusedRedos=True):
           ret = generatorFn(*args, **kwargs)
-        self._processCallbacks()
+        self._processCallbacks(self.actions[-1])
         return ret
 
       @wraps(generatorFn)
@@ -177,7 +178,7 @@ class ActionStack:
           # State change of application means old redos are invalid
           self.flushUnusedRedos()
         # Else: doesn't get added to the queue
-        self._processCallbacks()
+        self._processCallbacks(action)
         return ret
       if asGroup:
         return inner_group
@@ -185,10 +186,10 @@ class ActionStack:
         return inner_action
     return decorator
 
-  def _processCallbacks(self):
+  def _processCallbacks(self, lastAction=None):
     if self._curReceiver is self.actions:
       for callback in self.stackChangedCallbacks:
-        callback()
+        callback(lastAction)
 
   @property
   def undoDescr(self):
@@ -230,11 +231,14 @@ class ActionStack:
       self._curReceiver = self.actions
 
   def flushUnusedRedos(self):
+    flushed = False
     while self.canRedo:
       if self.actions[0] is self._savepoint:
         self._savepoint = EMPTY
       self.actions.popleft()
-    self._processCallbacks()
+      flushed = True
+    if flushed:
+      self._processCallbacks()
 
   def revertToSavepoint(self):
     if self._savepoint is EMPTY:
@@ -245,9 +249,12 @@ class ActionStack:
       actFn = self.undo
     else:
       actFn = self.redo
+    reverted = False
     while self.changedSinceLastSave:
       actFn()
-    self._processCallbacks()
+      reverted = True
+    if reverted:
+      self._processCallbacks()
 
   def redo(self):
     """
@@ -263,7 +270,7 @@ class ActionStack:
     self.actions.rotate(-1)
     with self.ignoreActions():
       ret = self.actions[-1].forward(graceful=True)
-    self._processCallbacks()
+    self._processCallbacks(self.actions[-1])
     return ret
 
   def undo(self):
@@ -277,7 +284,8 @@ class ActionStack:
     with self.ignoreActions():
       ret = self.actions[-1].backward()
     self.actions.rotate(1)
-    self._processCallbacks()
+    # After rotation, action is now at spot 0
+    self._processCallbacks(self.actions[0])
     return ret
 
   def clear(self):
