@@ -860,7 +860,11 @@ class EditorPropsMixin:
     basePath = (cls.__groupingName__,)
     if basePath[0] == '':
       basePath = ()
-    obj = super().__new__(cls, *args, **kwargs)
+    # 'onject' doesn't like args/kwargs, but other subclasses do
+    if super().__new__ is object.__new__:
+      obj = super().__new__(cls)
+    else:
+      obj = super().__new__(cls, *args, **kwargs)
     with ParamEditor.setBaseRegisterPath(*basePath):
       # Check if kwargs are desired
       try:
