@@ -99,8 +99,8 @@ class ProcessIO(dict):
       unclaimedOverrideKeys = set(overriddenDefaults) - set(hyperParamKeys)
       for k in unclaimedOverrideKeys:
         outDict[k] = overriddenDefaults[k]
-        # TODO: How to determine whether these should be hyperparams as well? For now, since they cannot have
-        #   docs to accompany them, consider them non-hyperparams
+        hyperParamKeys.append(k)
+        # TODO: How to determine whether these should be hyperparams as well?
     # Make sure to avoid 'init got multiple values' error
     initSig = inspect.signature(cls.__init__).parameters
     keys = list(outDict)
