@@ -1314,12 +1314,11 @@ class FadeNotifyHandler(TimedMessageHandler):
     fadeMsg.setAttribute(QtCore.Qt.WidgetAttribute.WA_TransparentForMouseEvents)
     parent: QtWidgets.QMainWindow = self.getWin()
     if parent is not None:
-      parentPos = parent.pos()
       metrics = fadeMsg.fontMetrics()
       padding = (parent.width() - metrics.width(msg))//2
-      msgX = padding + parentPos.x()
+      msgX = padding
       # Make sure multiple messages don't overlap
-      msgY = int(0.05*parent.height()) + parentPos.y()
+      msgY = int(0.05*parent.height())
       msgY += self.getUniqueLblOffset(msgY)
       fadeMsg.move(msgX, msgY)
     anim = self.makeAnimation(fadeMsg, timeout_ms)
